import 'dart:async';

import 'package:flutter/material.dart';
import 'package:gmalpha_flutter/model/setting_model.dart';
import 'package:provider/provider.dart';
import 'package:rxdart/rxdart.dart';

/// BaseProvide
class BaseProvide with ChangeNotifier {
  CompositeSubscription compositeSubscription = CompositeSubscription();

  addSubscription(StreamSubscription subscription) {
    compositeSubscription.add(subscription);
  }

  @override
  void dispose() {
    super.dispose();
    compositeSubscription.dispose();
  }
}

abstract class PageProvideNode<T extends ChangeNotifier>
    extends StatelessWidget {
  Widget buildContent(BuildContext context);

  T getProvider();

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      builder: (_) => getProvider(),
      child: buildContent(context),
    );
  }
}

abstract class PageMultiProvideNode<T extends ChangeNotifier>
    extends StatelessWidget {
  Widget buildContent(BuildContext context);

  List<SingleChildCloneableWidget> getProviders();

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: getProviders(),
      child: buildContent(context),
    );
  }
}

abstract class BaseState<T extends StatefulWidget> extends State<T> {
  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }
}
