import 'dart:async';

import 'package:event_bus/event_bus.dart';
import 'package:flutter/material.dart';
import 'package:flutter_boost/flutter_boost.dart';
import 'package:gmalpha_flutter/macros/ALColors.dart';
import 'package:gmalpha_flutter/page/SettingPage.dart';
import 'package:provider/provider.dart';
import 'base/app_config.dart';
import 'base/base.dart';
import 'event/ThemeColorEvent.dart';
import 'model/setting_model.dart';
import 'simple_page_widgets.dart';
import 'comment_suggest.dart';

void main() async {
  await AppConfig.init();

  runApp(MyApplication());
}
class MyApplication extends PageMultiProvideNode {

  @override
  Widget buildContent(BuildContext context) => MyApp();

  @override
  List<SingleChildCloneableWidget> getProviders() {
    return AppConfig.list;
  }
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  EventBus eventBus = EventBus();
  StreamSubscription _colorSubscription;

  @override
  void initState() {
    super.initState();
    //event bus example
    _colorSubscription = eventBus.on<ThemeColorEvent>().listen((event) {
      print("==========${event.color}");
    });
    eventBus.fire(ThemeColorEvent(0xffffffff));

    FlutterBoost.singleton.registerPageBuilders({
      'first': (pageName, params, _) => FirstRouteWidget(),
      'second': (pageName, params, _) => SecondRouteWidget(),
      'setting_page': (pageName, params, _) => SettingPage(params),
      "page_a": (pageName, params, _) => SettingPage(params),
//      'tab': (pageName, params, _) => TabRouteWidget(),
//      'flutterFragment': (pageName, params, _) => FragmentRouteWidget(params),
//      'comment_suggest': (pageName, params, _) {
//        CommentSuggest(params);
//        print("comment_suggest ${params}");
//      },
//      ///可以在native层通过 getContainerParams 来传递参数
//      'flutterPage': (pageName, params, _) {
//        print("flutterPage params:$params");
//        return FlutterRouteWidget();
//      },
    });

    FlutterBoost.handleOnStartPage();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
    _colorSubscription.cancel();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Boost example',
      debugShowCheckedModeBanner: false,
//      initialRoute: '/test',//调试的时候可以打开
//      routes: {
//        '/': (context) => SettingPage({"Cookie":" _gm_token=7e48641558699683; sessionid=nb3ze4ur7ucosln8sd8pzwojddenv9ym; _gtid=a1bc0a387e1911e996b9525400fa516d4094"}),
//      },//调试的时候可以打开
//      builder: FlutterBoost.init(postPush: _onRoutePushed),
      home: SettingPage({
        "Cookie":
            " _gm_token=7e48641558699683; sessionid=nb3ze4ur7ucosln8sd8pzwojddenv9ym; _gtid=a1bc0a387e1911e996b9525400fa516d4094"
      }),
      theme: new ThemeData(
        primaryColor: Colors.white,
        appBarTheme: AppBarTheme(
            color: Color(Provider.of<SettingProvide>(context).color)),
        backgroundColor: Color(0xFFFFFFFF),
        accentColor: Color(0xFFFFFFFF),
        textTheme: TextTheme(
          //设置Material的默认字体样式
          body1: TextStyle(color: Color(0xFF888888), fontSize: 16.0),
        ),
        iconTheme: IconThemeData(
          color: Color(0xFFEFEFEF),
          size: 35.0,
        ),
      ),
    );
  }

  void _onRoutePushed(
      String pageName, String uniqueId, Map params, Route route, Future _) {
    print('---> _onRoutePushed pageName ' + pageName);
//    List<OverlayEntry> newEntries = route.overlayEntries
//        .map((OverlayEntry entry) => OverlayEntry(
//            builder: (BuildContext context) {
//              final pageWidget = entry.builder(context);
//              return Stack(
//                children: <Widget>[
//                  pageWidget,
//                  Positioned(
//                    child: Text(
//                      "pageName:$pageName\npageWidget:${pageWidget.toStringShort()}",
//                      style: TextStyle(fontSize: 12.0, color: Colors.red),
//                    ),
//                    left: 8.0,
//                    top: 8.0,
//                  )
//                ],
//              );
//            },
//            opaque: entry.opaque,
//            maintainState: entry.maintainState))
//        .toList(growable: true);
//
//    route.overlayEntries.clear();
//    route.overlayEntries.addAll(newEntries);
  }
}
